@@ -2,7 +2,7 @@
 
 __author__ = 'Fabio Caccamo'
 __copyright__ = 'Copyright (c) 2019 Fabio Caccamo'
-__description__ = 'python-benedict is the Python dictionary that helps humans dealing with evil data.'
+__description__ = 'python-benedict is the Python dictionary for humans dealing with evil data.'
 __license__ = 'MIT'
 __title__ = 'benedict'
-__version__ = '0.1.0'
\ No newline at end of file
+__version__ = '0.2.0'
\ No newline at end of file
